/***************************************************************************
*   Copyright (C) 2003 by Sandro Giessl                                   *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#include <kconfig.h>
#include <klocale.h>
#include <kglobal.h>
#include <qcheckbox.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qwhatsthis.h>

#include "porcelainconfig.h"
#include "configdialog.h"

PorcelainConfig::PorcelainConfig(KConfig* config, QWidget* parent)
    : QObject(parent), m_config(0), m_dialog(0)
{
    // Create the configuration object.
    m_config = new KConfig("kwinporcelainrc");
    KGlobal::locale()->insertCatalogue("kwin_porcelain_config");

    // Create and show the configuration dialog.
    m_dialog = new ConfigDialog(parent);
    m_dialog->show();

    // Load the configuration.
    load(config);

    // Setup the connections.
    connect(m_dialog->m_titleSize, SIGNAL(valueChanged(int)), this, SIGNAL(changed()));
    connect(m_dialog->m_invertButton, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
    connect(m_dialog->m_centerTitle, SIGNAL(toggled(bool)), this, SIGNAL(changed()));

}

PorcelainConfig::~PorcelainConfig()
{
    if (m_dialog) delete m_dialog;
    if (m_config) delete m_config;
}

void PorcelainConfig::load(KConfig*)
{
    m_config->setGroup("General");

    int titleSize = m_config->readNumEntry("TitleSize", 30);
    m_dialog->m_titleSize->setValue(titleSize);
    // int borderSize = (titleSize/4)-1;
    // int buttonSize = (titleSize/2)+6;
    bool invertButton = m_config->readBoolEntry("InvertButton", false);
    m_dialog->m_invertButton->setChecked(invertButton);
    bool centerTitle = m_config->readBoolEntry("CenterTitle", false);
    m_dialog->m_centerTitle->setChecked(centerTitle);
}

void PorcelainConfig::save(KConfig*)
{
    m_config->setGroup("General");

    m_config->writeEntry("TitleSize", m_dialog->m_titleSize->value());
    m_config->writeEntry("InvertButton", m_dialog->m_invertButton->isChecked());
    m_config->writeEntry("CenterTitle", m_dialog->m_centerTitle->isChecked());
    m_config->sync();
}

void PorcelainConfig::defaults()
{
    m_dialog->m_titleSize->setValue(30);
    m_dialog->m_invertButton->setChecked(false);
    m_dialog->m_centerTitle->setChecked(false);
}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

extern "C"
{
    QObject* allocate_config(KConfig* config, QWidget* parent) {
        return (new PorcelainConfig(config, parent));
    }
}

#include "porcelainconfig.moc"
